<?php

namespace Drupal\data_pipelines\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\data_pipelines\Entity\Dataset;
use Drupal\data_pipelines\Entity\DatasetInterface;
use Drupal\data_pipelines\Form\DatasetBatchOperations;
use Drush\Commands\DrushCommands;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Data pipelines drush commands.
 */
class DataPipelinesCommands extends DrushCommands {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Creates a DataPipelinesCommand object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct();
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Provide a list of datasets if argument is not provided.
   *
   * @hook interact data-pipelines:reindex
   */
  public function datasetReindexInteract(InputInterface $input, OutputInterface $output) {
    if (!empty($input->getArgument('machine_name'))) {
      return;
    }

    $datasets = $this->entityTypeManager->getStorage('data_pipelines')->loadMultiple();
    $choices = [];
    foreach ($datasets as $dataset) {
      assert($dataset instanceof DatasetInterface);
      // Choices doe not support integer keys, so do some string manipulation.
      $choices[$dataset->getMachineName()] = $dataset->label();
    }
    $choice = $this->io()->choice(dt('Which dataset would you like to reindex'), $choices);

    $input->setArgument('machine_name', $choice);
  }

  /**
   * Rebulid the index for a dataset.
   *
   * @param string $machine_name
   *   The data pipelines machine_name to rebuild.
   *
   * @command data-pipelines:reindex
   *
   * @validate-module-enabled data_pipelines
   */
  public function datasetReindex(string $machine_name) {
    $dataset = DataSet::loadByMachineName($machine_name);

    assert($dataset instanceof DatasetInterface);
    batch_set(DatasetBatchOperations::batchForDataset($dataset));
    drush_backend_batch_process();
  }

}
