<?php

declare(strict_types=1);

namespace Drupal\data_pipelines\Destination;

use Drupal\data_pipelines\Entity\DatasetInterface;

/**
 * Processing operation enum.
 */
enum ProcessingOperationEnum: string {

  case BEGIN = 'begin';
  case PROCESS_CHUNK = 'process_chunk';
  case END = 'end';
  case PROCESS_CLEANUP = 'process_cleanup';

  /**
   * Gets the ID for this operation.
   *
   * @return string
   *   ID representation of the enum.
   */
  public function id(): string {
    return $this->value;
  }

  /**
   * Process the operation.
   *
   * @param \Drupal\data_pipelines\Destination\DatasetDestinationPluginInterface $destinationPlugin
   *   Plugin to perform processing.
   * @param \Drupal\data_pipelines\Entity\DatasetInterface $dataset
   *   Dataset.
   * @param \Drupal\data_pipelines\Destination\ProcessingOperation $operation
   *   Operation.
   *
   * @return bool
   *   Processing result.
   */
  public function process(DatasetDestinationPluginInterface $destinationPlugin, DatasetInterface $dataset, ProcessingOperation $operation): bool {
    return match($this) {
      self::BEGIN => $destinationPlugin->beginProcessing($dataset),
      self::END => $destinationPlugin->endProcessing($dataset),
      self::PROCESS_CLEANUP => $destinationPlugin->processCleanup($dataset, $operation->getProcessingData()),
      default => $destinationPlugin->processChunk($dataset, $operation->getProcessingData()),
    };
  }

}
